@@ -10,20 +10,24 @@ header('Cache-Control: no-cache, must-revalidate');
 $ajax_service_status = [];
 $services = ['httpd', 'php-fpm', 'docker', 'proftpd'];
 foreach ($services as $service) {
+    // Validate service name to prevent command injection
+    $service = escapeshellarg($service);
     $status = trim(shell_exec("systemctl is-active $service 2>/dev/null"));
-    $ajax_service_status[$service] = $status;
+    $ajax_service_status[trim($service, "'")] = $status;
 }
 
 // Get current container status
 $ajax_container_status = [];
 $containers = ['mysql', 'haproxy-manager', 'memcache'];
 foreach ($containers as $container) {
-    $status = trim(shell_exec("docker ps --filter name=$container --format '{{.Status}}' 2>/dev/null"));
+    // Validate container name to prevent command injection
+    $container_escaped = escapeshellarg($container);
+    $status = trim(shell_exec("docker ps --filter name=$container_escaped --format '{{.Status}}' 2>/dev/null"));
     if (!empty($status)) {
         $ajax_container_status[$container] = 'running';
     } else {
         // Check if container exists but is stopped
-        $exists = trim(shell_exec("docker ps -a --filter name=$container --format '{{.Names}}' 2>/dev/null"));
+        $exists = trim(shell_exec("docker ps -a --filter name=$container_escaped --format '{{.Names}}' 2>/dev/null"));
         $ajax_container_status[$container] = !empty($exists) ? 'stopped' : 'not_found';
     }
 }
